# =========================================================================== #
# Gemspec for Project SaveFile.
# =========================================================================== #
require 'save_file/version/version.rb'
require 'roebe'

Gem::Specification.new { |s|

  s.name     = 'save_file'
  s.version  = SaveFile::VERSION
  s.date     = Time.now.strftime('%Y-%m-%d')
  
  DESCRIPTION = <<-EOF

This class can be used to save a file in a convenient way,
by giving you a very simple save-file functionality.

I liked the name 'save_file()' a lot, and I found that I
was  needing such a functionality in many of my projects,
so I made a tiny gem that would do exactly this. Note
that the recommended methods are write_what_into() and
append_what_into() - at the least for me, this is easy
to remember.

Of course you can use File.open() or File.new() already
as-is in block variant, so there is no need to use a 
gem like this one here - but I did not want to have to
deal with file permissions or missing files or similar
all on my own, via the File API that I do not as easily
remember. So I just wrote an API that is simple enough
for my use cases. 

Usage examples:

    require 'save_file'
    save_what_into('test', '/tmp/test.txt')

You can also use:

    SaveFile.write_what_into(what, into)
    SaveFile.append_what_into(what, into)

The main module can be included into a class,
which then will have these methods available.

This project has no external dependencies, deliberately 
so. It has to remain stand-alone.

Version 1.0.3 made it more clear when to use save_file()
and when to use append_into_file().
  EOF

  s.summary     = DESCRIPTION
  s.description = DESCRIPTION
  
  s.extra_rdoc_files = %w()
  
  s.authors    = ['Robert A. Heiler']
  s.email      = Roebe.email?
  these_files  = Dir['**/*']
  s.files      = these_files
  s.files     << 'README.md'
  s.license    = 'MIT'

  # ========================================================================= #
  # Show this when a user installs this project.
  # ========================================================================= #
  s.post_install_message = <<-EOF

This gem, called "save_file", can be used to quickly save content
into a file. This is easily possible in ruby with File.open {} 
as-is, but I wanted to have this available as a toplevel-method
on module SaveFile.s.required_ruby_version     = '>= '+Roebe.second_most_stable_version_of_ruby

See the following usage example:

  require 'save_file'

  SaveFile.write_what_into("Hello world!", 'foobar.txt')

  EOF

  s.homepage = 'https://rubygems.org/gems/save_file'

  s.required_ruby_version     = '>= '+Roebe.third_most_stable_version_of_ruby
  s.required_rubygems_version = '>= '+Gem::VERSION
  s.rubygems_version          = '>= '+Gem::VERSION

}